#
# spec file for package jitterentropy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects

Name:           jitterentropy
VCS: https://src.suse.de/SLFO-pool/jitterentropy?trackingbranch=main#5dd3d6d0da1d30dcdf9b41a78c864f86663926c8be73a7b95bc5c6fddafc4063
Summary:        A userspace library for jitter entropy generation
License:        BSD-3-Clause OR GPL-2.0-or-later
Group:          Development/Tools/Other
Version:        3.6.3
Release:        160000.2.1
URL:            https://github.com/smuellerDD/jitterentropy-library
Source0:        https://github.com/smuellerDD/jitterentropy-library/archive/refs/tags/v%{version}.tar.gz
Source1:        baselibs.conf
Patch1:         jitterentropy-split-internal-header.patch
Patch2:         jitterentropy-with-debug.patch

%description
The Jitter RNG provides a noise source using the CPU execution
timing jitter. It depends on a high-resolution time stamp.

The design of this RNG is given in the documentation found at
http://www.chronox.de/jent.html . This documentation also covers the full
assessment of the SP800-90B compliance as well as all required test code.

%package -n libjitterentropy3
Summary:        Jitter entropy generator shared library
Group:          System/Libraries

%description -n libjitterentropy3
The Jitter RNG provides a noise source using the CPU execution
timing jitter. It depends on a high-resolution time stamp.

This package contains the shared library.

%package devel
Summary:        Jitter entropy generator development header and library
Group:          Development/Tools/Other
Requires:       libjitterentropy3 = %{version}

%description devel
The Jitter RNG provides a noise source using the CPU execution
timing jitter. It depends on a high-resolution time stamp.

This package contains the development header and library.

%package devel-static
Summary:        Jitter entropy generator static library
Group:          Development/Tools/Other

%description devel-static
The Jitter RNG provides a noise source using the CPU execution
timing jitter. It depends on a high-resolution time stamp.

This package contains the static library.

%prep
%autosetup -n jitterentropy-library-%version

%build
%set_build_flags
%make_build PREFIX="%_prefix" LIBDIR="%_lib"

%install
%make_install PREFIX="%_prefix" LIBDIR="%_lib" all install-static

%post -n libjitterentropy3 -p /sbin/ldconfig
%postun -n libjitterentropy3 -p /sbin/ldconfig

%files devel
%license LICENSE.gplv2 LICENSE LICENSE.bsd
%_includedir/jitterentropy-base-user.h
%_includedir/jitterentropy.h
%_libdir/libjitterentropy.so
%_mandir/man3/jitterentropy.3*

%files devel-static
%license LICENSE.gplv2 LICENSE LICENSE.bsd
%_libdir/libjitterentropy.a

%files -n libjitterentropy3
%license LICENSE.gplv2 LICENSE LICENSE.bsd
%_libdir/libjitterentropy.so.3
%_libdir/libjitterentropy.so.%version

%changelog
* Wed Apr 30 2025 pmonreal@suse.com
- Update to 3.6.3: [bsc#1242050]
  * Correct time stamp processing on AIX
  * Use high-resolution time stamp on Apple Silicon
  * GCD power-up test: consider OSR
  * Remove patches fixed in the update:
  - jitterentropy-fix-a-stack-corruption-on-s390x.patch
  * Rebase patches:
  - jitterentropy-split-internal-header.patch
  - jitterentropy-with-debug.patch
- Update to 3.6.2:
  * Fix RCT re-initialization in jent_read_entropy_safe
  * simplify test code
  * improve keyword portability
- Update to 3.6.1:
  * Add more test code
  * Add support for SunPRO compiler
  * Fix compilation on OpenBSD by replacing sed with tr
  * internal timer: Add support for Apple
  * Various small fixes to compilation to imporve portability
- Update to 3.6.0:
  * Remove bi-modal behavior of conditioning function
  * Make jent_read_entropy_safe safer by retrying the health test
  * Move the version information to make them available at compile time
- Update to 3.5.0:
  * add distinction between intermittent and permanent health failure
  * add compile time option to allow configuring a mask to reduce the
    size of the time stamp used for the APT
* Wed Dec  6 2023 guillaume.gardet@opensuse.org
- Make use of distro flags with %%set_build_flags
* Wed Mar 22 2023 pmonreal@suse.com
- Fix a stack corruption on s390x: [bsc#1209627]
  * Output size of the STCKE command on s390x is 16 bytes, compared
    to 8 bytes of the STCK command. Fix a stack corruption in the
    s390x version of jent_get_nstime(). Add some more detailed
    information on the STCKE command.
  * github.com/smuellerDD/jitterentropy-library/commit/7bf9f85
  * Add jitterentropy-fix-a-stack-corruption-on-s390x.patch
* Thu Jan 26 2023 meissner@suse.com
- jitterentropy-with-debug.patch: build with debuginfo (bsc#1207789)
* Tue Sep 13 2022 meissner@suse.com
- jitterentropy-split-internal-header.patch:
  Hide the non-GNUC constructs that are library internal from the
  exported header. (bsc#1202870)
* Mon Sep 12 2022 meissner@suse.com
- updated to 3.4.1
  * add FIPS 140 hints to man page
  * simplify the test tool to search for optimal configurations
  * fix: jent_loop_shuffle: re-add setting the time that was lost with 3.4.0
  * enhancement: add ARM64 assembler code to read high-res timer
* Wed Aug  3 2022 meissner@suse.com
- updated to 3.4.0
  * enhancement: add API call jent_set_fips_failure_callback as requested by Daniel Ojalvo
  * fix: Change the SHA-3 integration: The entropy pool is now a SHA-3 state.
  It is filled with the time delta containing entropy and auxiliary data that does not contain entropy using a SHA update operation. The auxiliary data is calculated by a SHA-3 hashing of some varying state data. The time delta that contains entropy is measured about the SHA-3 hasing of the auxiliary data. This satisfies FIPS 140-3 IG D.K resolutions 4, 6, and 8.
  * enhancement: add CMake support by Andrew Hopkins
- updated to 3.3.1
  * fix: bug fix in initialization logic by Vladis Dronov <vdronov@redhat.com>
  * fix: use __asm__ instead of asm to suit the C11 standard
- added a -devel-static package to be able to link it static.
* Tue Sep 28 2021 jengelh@inai.de
- Trim conjecture from descriptions.
* Tue Sep 21 2021 meissner@suse.com
- add a userspace jitter entropy generator library
